@@ -1,6 +1,8 @@
 #ifndef POLICYTYPE_H
 #define POLICYTYPE_H
 
+#include <QtGlobal>
+
 /*!
   \namespace Sailfish::PolicyTypes
   \internal
@@ -24,13 +26,13 @@ enum PolicyType {
     DeviceResetEnabled,
     ScreenshotEnabled,
     MobileNetworkSettingsEnabled,
-    UsbMassStorageEnabled,
+    UsbMassStorageEnabled Q_DECL_DEPRECATED,
     UsbDeveloperModeEnabled,
     UsbMtpEnabled,
-    UsbHostEnabled,
-    UsbConnectionSharingEnabled,
-    UsbDiagnosticModeEnabled,
-    UsbAdbEnabled,
+    UsbHostEnabled Q_DECL_DEPRECATED,
+    UsbConnectionSharingEnabled Q_DECL_DEPRECATED,
+    UsbDiagnosticModeEnabled Q_DECL_DEPRECATED,
+    UsbAdbEnabled Q_DECL_DEPRECATED,
     DateTimeSettingsEnabled,
     MicrophoneEnabled,
     FlightModeToggleEnabled,
@@ -46,6 +48,8 @@ enum PolicyType {
     BluetoothToggleEnabled,
     VoiceCallEnabled,
     SMSEnabled,
+    SdMountEnabled,
+    UsbMountEnabled,
 };
 
 #ifdef  __cplusplus
